==> chaosmesh-model-6.6.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/StressCPUSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StressCPUSpecFluentImpl<A extends StressCPUSpecFluent<A>> extends BaseFluent<A> implements StressCPUSpecFluent<A>{
  public StressCPUSpecFluentImpl() {
  }
  public StressCPUSpecFluentImpl(StressCPUSpec instance) {
    this.withLoad(instance.getLoad()); 
    this.withOptions(instance.getOptions()); 
    this.withWorkers(instance.getWorkers()); 
  }
  private Integer load;
  private String options;
  private Integer workers;
  public Integer getLoad() {
    return this.load;
  }
  public A withLoad(Integer load) {
    this.load=load; return (A) this;
  }
  public Boolean hasLoad() {
    return this.load != null;
  }
  public String getOptions() {
    return this.options;
  }
  public A withOptions(String options) {
    this.options=options; return (A) this;
  }
  public Boolean hasOptions() {
    return this.options != null;
  }
  public Integer getWorkers() {
    return this.workers;
  }
  public A withWorkers(Integer workers) {
    this.workers=workers; return (A) this;
  }
  public Boolean hasWorkers() {
    return this.workers != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StressCPUSpecFluentImpl that = (StressCPUSpecFluentImpl) o;
    if (load != null ? !load.equals(that.load) :that.load != null) return false;
    if (options != null ? !options.equals(that.options) :that.options != null) return false;
    if (workers != null ? !workers.equals(that.workers) :that.workers != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(load,  options,  workers,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (load != null) { sb.append("load:"); sb.append(load + ","); }
    if (options != null) { sb.append("options:"); sb.append(options + ","); }
    if (workers != null) { sb.append("workers:"); sb.append(workers); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/StressCPUSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StressCPUSpecFluentImpl<A extends StressCPUSpecFluent<A>> extends BaseFluent<A> implements StressCPUSpecFluent<A>{
  public StressCPUSpecFluentImpl() {
  }
  public StressCPUSpecFluentImpl(StressCPUSpec instance) {
    if (instance != null) {
      this.withLoad(instance.getLoad());
      this.withOptions(instance.getOptions());
      this.withWorkers(instance.getWorkers());
    }
  }
  private Integer load;
  private String options;
  private Integer workers;
  public Integer getLoad() {
    return this.load;
  }
  public A withLoad(Integer load) {
    this.load=load; return (A) this;
  }
  public Boolean hasLoad() {
    return this.load != null;
  }
  public String getOptions() {
    return this.options;
  }
  public A withOptions(String options) {
    this.options=options; return (A) this;
  }
  public Boolean hasOptions() {
    return this.options != null;
  }
  public Integer getWorkers() {
    return this.workers;
  }
  public A withWorkers(Integer workers) {
    this.workers=workers; return (A) this;
  }
  public Boolean hasWorkers() {
    return this.workers != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StressCPUSpecFluentImpl that = (StressCPUSpecFluentImpl) o;
    if (!java.util.Objects.equals(load, that.load)) return false;

    if (!java.util.Objects.equals(options, that.options)) return false;

    if (!java.util.Objects.equals(workers, that.workers)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(load,  options,  workers,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (load != null) { sb.append("load:"); sb.append(load + ","); }
    if (options != null) { sb.append("options:"); sb.append(options + ","); }
    if (workers != null) { sb.append("workers:"); sb.append(workers); }
    sb.append("}");
    return sb.toString();
  }
  
}
